# _leetstalker_
Fetch user stats from leetcode

## Installation
Install using [pipx](https://pipx.pypa.io/stable/)
```sh
pipx install leetstalker
```

## Configuration
By default, a configuration file is expected at `~/.config/leetstalker/config.toml`
### Example configuration
```toml
users = [
  'larryNY',
  'nairvarun'
]
```

## Usage
```sh
leetstalker --help
```